prometheus_client: Python client for the systems monitoring and alerting toolkit Prometheus
===========================================================================================

Description
-----------

The official Python 2 and 3 client for Prometheus (see
https://prometheus.io), an open-source systems monitoring and alerting
toolkit.
